Learn R Programming

xptr (version 1.2.0)

set_xptr_protected: Set a protected R object to the external pointer.

Description

Set a protected R object to the external pointer.

Usage

set_xptr_protected(s, protected)

Value

No return value as the function is called for its side effect

Arguments

s

An externalptr object

protected

An R object